@@ -1,9 +1,16 @@
-/* hop.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -13,9 +20,9 @@ static integer c__3 = 3;
 static integer c__400 = 400;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
-/* Main program */ MAIN__(void)
+/* Main program */ int MAIN__(void)
 {
     /* Builtin functions */
     double sin(doublereal), cos(doublereal);
@@ -24,20 +31,18 @@ static integer c__400 = 400;
 
     /* Local variables */
     static integer n;
-    static real t, x[400], y[400];
-    extern /* Subroutine */ int grcls_(void), grfrm_(void), gropn_(integer *);
-    static real dt;
-    extern /* Subroutine */ int usgrph_(integer *, real *, real *), sgpwsn_(
-	    void), ussttl_(char *, char *, char *, char *, ftnlen, ftnlen, 
-	    ftnlen, ftnlen);
+    static real t, x[400], y[400], dt;
     static integer iws;
+    extern /* Subroutine */ int grcls_(void), grfrm_(void), gropn_(integer *),
+	     usgrph_(integer *, real *, real *), sgpwsn_(void), ussttl_(char *
+	    , char *, char *, char *, ftnlen, ftnlen, ftnlen, ftnlen);
 
     /* Fortran I/O blocks */
     static cilist io___6 = { 0, 6, 0, 0, 0 };
     static cilist io___7 = { 0, 5, 0, 0, 0 };
 
 
-/* -- ꥵ塼ο ---- */
+/* -- リサジューの図 ---- */
     dt = .015747318295739349f;
     for (n = 1; n <= 400; ++n) {
 	t = dt * (n - 1);
@@ -45,7 +50,7 @@ static integer c__400 = 400;
 	y[n - 1] = cos(t * 5.f) * .001f + 6.f;
 /* L10: */
     }
-/* --  ---- */
+/* -- グラフ ---- */
     s_wsle(&io___6);
     do_lio(&c__9, &c__1, " WORKSTATION ID (I)  ? ;", (ftnlen)24);
     e_wsle();
