@@ -1,9 +1,16 @@
-/* sgpk06.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -25,9 +32,9 @@ static real c_b48 = .5f;
 static logical c_true = TRUE_;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
-/* Main program */ MAIN__(void)
+/* Main program */ int MAIN__(void)
 {
     /* Builtin functions */
     double sin(doublereal), cos(doublereal);
@@ -36,16 +43,14 @@ static logical c_true = TRUE_;
 
     /* Local variables */
     static integer i__;
-    static real r__, x[37], y[37];
+    static real r__, x[37], y[37], dt, xc, yc;
+    static integer iws;
     extern /* Subroutine */ int sgcls_(void), sgfrm_(void), sgopn_(integer *),
 	     sgplu_(integer *, real *, real *), sgtxu_(real *, real *, char *,
-	     ftnlen);
-    static real dt, xc, yc;
-    extern /* Subroutine */ int sgspli_(integer *), sglset_(char *, logical *,
-	     ftnlen), sgswnd_(real *, real *, real *, real *), sgstrf_(void), 
-	    sgstrn_(integer *), sgpwsn_(void), sgstxi_(integer *), sgsvpt_(
-	    real *, real *, real *, real *), slpvpr_(integer *);
-    static integer iws;
+	     ftnlen), sgspli_(integer *), sglset_(char *, logical *, ftnlen), 
+	    sgswnd_(real *, real *, real *, real *), sgstrf_(void), sgstrn_(
+	    integer *), sgpwsn_(void), sgstxi_(integer *), sgsvpt_(real *, 
+	    real *, real *, real *), slpvpr_(integer *);
 
     /* Fortran I/O blocks */
     static cilist io___8 = { 0, 6, 0, 0, 0 };
@@ -89,7 +94,7 @@ static logical c_true = TRUE_;
     sgswnd_(&c_b9, &c_b10, &c_b9, &c_b10);
 /* <-- 1x1 */
     sgsvpt_(&c_b25, &c_b26, &c_b27, &c_b28);
-/* <--  view port */
+/* <-- 小さな view port */
     sgstrn_(&c__1);
     sgstrf_();
     slpvpr_(&c__1);
@@ -99,7 +104,7 @@ static logical c_true = TRUE_;
 /*                XMIN, XMAX, YMIN, YMAX */
 /* <-- */
     sgswnd_(&c_b9, &c_b10, &c_b35, &c_b36);
-/* <-- 椬 window */
+/* <-- ゆがんだ window */
     sgsvpt_(&c_b27, &c_b28, &c_b27, &c_b28);
     sgstrn_(&c__1);
     sgstrf_();
@@ -110,7 +115,7 @@ static logical c_true = TRUE_;
 /*                XMIN, XMAX, YMIN, YMAX */
 /* <-- */
     sgswnd_(&c_b9, &c_b10, &c_b47, &c_b48);
-/* <-- Ϥ߽Ф window */
+/* <-- はみ出し window */
     sgsvpt_(&c_b25, &c_b26, &c_b25, &c_b26);
     sgstrn_(&c__1);
     sgstrf_();
