@@ -1,9 +1,16 @@
-/* vstl01.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -11,9 +18,9 @@ static integer c__1 = 1;
 static integer c__3 = 3;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
-/* Main program */ MAIN__(void)
+/* Main program */ int MAIN__(void)
 {
     /* Initialized data */
 
@@ -27,12 +34,11 @@ static integer c__3 = 3;
     integer s_wsfe(cilist *), do_fio(integer *, char *, ftnlen), e_wsfe(void);
 
     /* Local variables */
-    static integer i__, j;
+    static integer i__, j, nw1[3];
+    static real wz1[6]	/* was [3][2] */;
     extern /* Subroutine */ int vs1din_(real *, integer *, integer *, real *),
 	     vs1int_(real *, integer *, integer *), vs1out_(real *, integer *,
 	     integer *);
-    static integer nw1[3];
-    static real wz1[6]	/* was [3][2] */;
 
     /* Fortran I/O blocks */
     static cilist io___2 = { 0, 6, 0, "(A)", 0 };
