@@ -1,9 +1,16 @@
-/* map3d2.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -26,9 +33,9 @@ static integer c__30 = 30;
 static integer c__37 = 37;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
-/* Main program */ MAIN__(void)
+/* Main program */ int MAIN__(void)
 {
     /* System generated locals */
     integer i__1;
@@ -40,11 +47,12 @@ static integer c__37 = 37;
 	    e_wsle(void), s_rsle(cilist *), e_rsle(void);
 
     /* Local variables */
+    static integer i__, j, k;
+    static real p[1369]	/* was [37][37] */;
+    static integer iws;
     static real alat, alon;
     static integer ipat;
     static real slat, tlev1, tlev2;
-    static integer i__, j, k;
-    static real p[1369]	/* was [37][37] */;
     extern /* Subroutine */ int grcls_(void), grfrm_(void), gropn_(integer *),
 	     udgclb_(real *, integer *, integer *, integer *, real *), 
 	    umpglb_(void), uetone_(real *, integer *, integer *, integer *), 
@@ -54,7 +62,6 @@ static integer c__37 = 37;
 	    *, real *, real *), sgstrf_(void), sgstrn_(integer *), sgpwsn_(
 	    void), uestlv_(real *, real *, integer *), sgsvpt_(real *, real *,
 	     real *, real *), sgstxy_(real *, real *, real *, real *);
-    static integer iws;
 
     /* Fortran I/O blocks */
     static cilist io___7 = { 0, 6, 0, 0, 0 };
