@@ -1,9 +1,16 @@
-/* uxyz6.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -26,15 +33,16 @@ static real c_b32 = 100.f;
 static integer c_n1 = -1;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
-/* Main program */ MAIN__(void)
+/* Main program */ int MAIN__(void)
 {
     /* Builtin functions */
     integer s_wsle(cilist *), do_lio(integer *, integer *, char *, ftnlen), 
 	    e_wsle(void), s_rsle(cilist *), e_rsle(void);
 
     /* Local variables */
+    static integer iws;
     extern /* Subroutine */ int grcls_(void), grfrm_(void), gropn_(integer *),
 	     ucyacl_(char *, integer *, integer *, ftnlen), uzfact_(real *), 
 	    grswnd_(real *, real *, real *, real *), grstrf_(void), grstrn_(
@@ -44,7 +52,6 @@ static integer c_n1 = -1;
 	    uzlset_(char *, logical *, ftnlen), uxmttl_(char *, char *, real *
 	    , ftnlen, ftnlen), uxsttl_(char *, char *, real *, ftnlen, ftnlen)
 	    , uysttl_(char *, char *, real *, ftnlen, ftnlen);
-    static integer iws;
 
     /* Fortran I/O blocks */
     static cilist io___1 = { 0, 6, 0, 0, 0 };
