@@ -1,34 +1,41 @@
-/* sglqnp.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
 static integer c__3 = 3;
-static integer c__24 = 24;
+static integer c__25 = 25;
 
 /* ----------------------------------------------------------------------- */
 /*     LOGICAL PARAMETER CONTROL */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int sglqnp_0_(int n__, integer *ncp, char *cp, integer *idx, 
 	logical *lpara, integer *in, ftnlen cp_len)
 {
     /* Initialized data */
 
-    static char cparas[8*24] = "LCLIP   " "LCHAR   " "LLNINT  " "LGCINT  " 
+    static char cparas[8*25] = "LCLIP   " "LCHAR   " "LLNINT  " "LGCINT  " 
 	    "LSOFTF  " "LCL2TN  " "LCNTL   " "LFULL   " "LFPROP  " "LROT    " 
 	    "LBUFF   " "LCURV   " "LPROP   " "LUARW   " "LARROW  " "LATONE  " 
-	    "LDEG    " "LCORNER " "LTITLE  " "LWIDE   " "L2TO3   " "LXLOG3  " 
-	    "LYLOG3  " "LZLOG3  ";
-    static logical lx[24] = { FALSE_,FALSE_,FALSE_,TRUE_,FALSE_,FALSE_,FALSE_,
-	    FALSE_,FALSE_,FALSE_,TRUE_,TRUE_,TRUE_,TRUE_,FALSE_,FALSE_,TRUE_,
-	    TRUE_,TRUE_,FALSE_,FALSE_,FALSE_,FALSE_,FALSE_ };
-    static char cparal[40*24] = "ENABLE_CLIPPING                         " 
+	    "LDEG    " "LCORNER " "LTITLE  " "LWIDE   " "LFGBG   " "L2TO3   " 
+	    "LXLOG3  " "LYLOG3  " "LZLOG3  ";
+    static logical lx[25] = { FALSE_,FALSE_,FALSE_,TRUE_,TRUE_,FALSE_,FALSE_,
+	    FALSE_,TRUE_,FALSE_,TRUE_,TRUE_,TRUE_,TRUE_,FALSE_,FALSE_,TRUE_,
+	    FALSE_,TRUE_,FALSE_,FALSE_,FALSE_,FALSE_,FALSE_,FALSE_ };
+    static char cparal[40*25] = "ENABLE_CLIPPING                         " 
 	    "ENABLE_LINE_LABELING                    " "ENABLE_LINEAR_INTERP"
 	    "OLATION             " "ENABLE_GREATCIRCLE_INTERPOLATION        " 
 	    "ENABLE_SOFTFILL                         " "ENABLE_COLOR_SUBSTIT"
@@ -41,10 +48,10 @@ static integer c__24 = 24;
 	    "                    " "ENABLE_ARROWHEAD_SHADE                  " 
 	    "USE_DEGREE                              " "DRAW_CORNERMARK     "
 	    "                    " "DRAW_PAGE_TITLE                         " 
-	    "****LWIDE                               " "****L2TO3           "
-	    "                    " "++++LXLOG3                              " 
-	    "++++LYLOG3                              " "++++LZLOG3          "
-	    "                    ";
+	    "****LWIDE                               " "****LFGBG           "
+	    "                    " "****L2TO3                               " 
+	    "++++LXLOG3                              " "++++LYLOG3          "
+	    "                    " "++++LZLOG3                              ";
     static logical lfirst = TRUE_;
 
     /* System generated locals */
@@ -56,9 +63,9 @@ static integer c__24 = 24;
 	     s_copy(char *, char *, ftnlen, ftnlen);
 
     /* Local variables */
+    static integer n;
     extern integer lenc_(char *, ftnlen);
     static char cmsg[80];
-    static integer n;
     extern logical lchreq_(char *, char *, ftnlen, ftnlen);
     extern /* Subroutine */ int msgdmp_(char *, char *, char *, ftnlen, 
 	    ftnlen, ftnlen), rllget_(char *, logical *, integer *, ftnlen), 
@@ -75,12 +82,12 @@ static integer c__24 = 24;
 	}
 
 /*     / LONG  NAME / */
-    *ncp = 24;
+    *ncp = 25;
     return 0;
 /* ----------------------------------------------------------------------- */
 
 L_sglqid:
-    for (n = 1; n <= 24; ++n) {
+    for (n = 1; n <= 25; ++n) {
 	if (lchreq_(cp, cparas + (n - 1 << 3), cp_len, (ftnlen)8) || lchreq_(
 		cp, cparal + (n - 1) * 40, cp_len, (ftnlen)40)) {
 	    *idx = n;
@@ -98,7 +105,7 @@ L_sglqid:
 /* ----------------------------------------------------------------------- */
 
 L_sglqcp:
-    if (1 <= *idx && *idx <= 24) {
+    if (1 <= *idx && *idx <= 25) {
 	s_copy(cp, cparas + (*idx - 1 << 3), cp_len, (ftnlen)8);
     } else {
 	msgdmp_("E", "SGLQCP", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
@@ -108,7 +115,7 @@ L_sglqcp:
 /* ----------------------------------------------------------------------- */
 
 L_sglqcl:
-    if (1 <= *idx && *idx <= 24) {
+    if (1 <= *idx && *idx <= 25) {
 	s_copy(cp, cparal + (*idx - 1) * 40, cp_len, (ftnlen)40);
     } else {
 	msgdmp_("E", "SGLQCL", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
@@ -119,11 +126,11 @@ L_sglqcl:
 
 L_sglqvl:
     if (lfirst) {
-	rtlget_("SG", cparas, lx, &c__24, (ftnlen)2, (ftnlen)8);
-	rllget_(cparal, lx, &c__24, (ftnlen)40);
+	rtlget_("SG", cparas, lx, &c__25, (ftnlen)2, (ftnlen)8);
+	rllget_(cparal, lx, &c__25, (ftnlen)40);
 	lfirst = FALSE_;
     }
-    if (1 <= *idx && *idx <= 24) {
+    if (1 <= *idx && *idx <= 25) {
 	*lpara = lx[*idx - 1];
     } else {
 	msgdmp_("E", "SGLQVL", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
@@ -134,11 +141,11 @@ L_sglqvl:
 
 L_sglsvl:
     if (lfirst) {
-	rtlget_("SG", cparas, lx, &c__24, (ftnlen)2, (ftnlen)8);
-	rllget_(cparal, lx, &c__24, (ftnlen)40);
+	rtlget_("SG", cparas, lx, &c__25, (ftnlen)2, (ftnlen)8);
+	rllget_(cparal, lx, &c__25, (ftnlen)40);
 	lfirst = FALSE_;
     }
-    if (1 <= *idx && *idx <= 24) {
+    if (1 <= *idx && *idx <= 25) {
 	lx[*idx - 1] = *lpara;
     } else {
 	msgdmp_("E", "SGLSVL", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
@@ -148,7 +155,7 @@ L_sglsvl:
 /* ----------------------------------------------------------------------- */
 
 L_sglqin:
-    for (n = 1; n <= 24; ++n) {
+    for (n = 1; n <= 25; ++n) {
 	if (lchreq_(cp, cparas + (n - 1 << 3), cp_len, (ftnlen)8) || lchreq_(
 		cp, cparal + (n - 1) * 40, cp_len, (ftnlen)40)) {
 	    *in = n;
