@@ -1,36 +1,44 @@
-/* swlqnp.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
 static integer c__3 = 3;
-static integer c__9 = 9;
+static integer c__13 = 13;
 
 /* ----------------------------------------------------------------------- */
-/*     LOGICAL PARAMETER CONTROL */
-/* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     SWLQNP / SWLQID / SWLQCP / SWLQVL / SWLSVL */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int swlqnp_0_(int n__, integer *ncp, char *cp, integer *idx, 
 	logical *lpara, integer *in, ftnlen cp_len)
 {
     /* Initialized data */
 
-    static char cparas[8*9] = "LWAIT   " "LWAIT0  " "LWAIT1  " "LKEY    " 
-	    "LDUMP   " "LALT    " "LCOLOR  " "LSEP    " "LPRINT  ";
-    static logical lx[9] = { TRUE_,FALSE_,TRUE_,TRUE_,FALSE_,FALSE_,TRUE_,
-	    FALSE_,FALSE_ };
-    static char cparal[40*9] = "WAIT                                    " 
+    static char cparas[8*13] = "LWAIT   " "LWAIT0  " "LWAIT1  " "LKEY    " 
+	    "LDUMP   " "LALT    " "LCOLOR  " "LSEP    " "LPRINT  " "LWND    " 
+	    "LFGBG   " "LCMCH   " "LSTDOT  ";
+    static logical lx[13] = { TRUE_,FALSE_,TRUE_,TRUE_,FALSE_,FALSE_,TRUE_,
+	    FALSE_,FALSE_,TRUE_,FALSE_,TRUE_,FALSE_ };
+    static char cparal[40*13] = "WAIT                                    " 
 	    "WAIT_OPENING                            " "WAIT_CLOSING        "
 	    "                    " "KEYCLICK                                " 
 	    "DUMP                                    " "ALTERNATE           "
 	    "                    " "ENABLE_COLOR_PS                         " 
 	    "SEPARATE                                " "PRINT               "
-	    "                    ";
+	    "                    " "SHOW_WINDOW                             " 
+	    "****LFGBG                               " "CMAP_CHANGABLE      "
+	    "                    " "PNG_STDOUT                              ";
     static logical lfirst = TRUE_;
 
     /* System generated locals */
@@ -42,15 +50,15 @@ static integer c__9 = 9;
 	     s_copy(char *, char *, ftnlen, ftnlen);
 
     /* Local variables */
+    static integer n;
     extern integer lenc_(char *, ftnlen);
     static char cmsg[80];
-    static integer n;
     extern logical lchreq_(char *, char *, ftnlen, ftnlen);
     extern /* Subroutine */ int msgdmp_(char *, char *, char *, ftnlen, 
 	    ftnlen, ftnlen), rllget_(char *, logical *, integer *, ftnlen), 
 	    rtlget_(char *, char *, logical *, integer *, ftnlen, ftnlen);
 
-/*     / SHORT NAME / */
+/* ---- SHORT NAME ---- */
     switch(n__) {
 	case 1: goto L_swlqid;
 	case 2: goto L_swlqcp;
@@ -60,13 +68,13 @@ static integer c__9 = 9;
 	case 6: goto L_swlqin;
 	}
 
-/*     / LONG NAME / */
-    *ncp = 9;
+/* ---- LONG NAME ---- */
+    *ncp = 13;
     return 0;
 /* ----------------------------------------------------------------------- */
 
 L_swlqid:
-    for (n = 1; n <= 9; ++n) {
+    for (n = 1; n <= 13; ++n) {
 	if (lchreq_(cp, cparas + (n - 1 << 3), cp_len, (ftnlen)8) || lchreq_(
 		cp, cparal + (n - 1) * 40, cp_len, (ftnlen)40)) {
 	    *idx = n;
@@ -84,7 +92,7 @@ L_swlqid:
 /* ----------------------------------------------------------------------- */
 
 L_swlqcp:
-    if (1 <= *idx && *idx <= 9) {
+    if (1 <= *idx && *idx <= 13) {
 	s_copy(cp, cparas + (*idx - 1 << 3), cp_len, (ftnlen)8);
     } else {
 	msgdmp_("E", "SWLQCP", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
@@ -94,7 +102,7 @@ L_swlqcp:
 /* ----------------------------------------------------------------------- */
 
 L_swlqcl:
-    if (1 <= *idx && *idx <= 9) {
+    if (1 <= *idx && *idx <= 13) {
 	s_copy(cp, cparal + (*idx - 1) * 40, cp_len, (ftnlen)40);
     } else {
 	msgdmp_("E", "SWLQCL", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
@@ -105,11 +113,11 @@ L_swlqcl:
 
 L_swlqvl:
     if (lfirst) {
-	rtlget_("SW", cparas, lx, &c__9, (ftnlen)2, (ftnlen)8);
-	rllget_(cparal, lx, &c__9, (ftnlen)40);
+	rtlget_("SW", cparas, lx, &c__13, (ftnlen)2, (ftnlen)8);
+	rllget_(cparal, lx, &c__13, (ftnlen)40);
 	lfirst = FALSE_;
     }
-    if (1 <= *idx && *idx <= 9) {
+    if (1 <= *idx && *idx <= 13) {
 	*lpara = lx[*idx - 1];
     } else {
 	msgdmp_("E", "SWLQVL", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
@@ -120,11 +128,11 @@ L_swlqvl:
 
 L_swlsvl:
     if (lfirst) {
-	rtlget_("SW", cparas, lx, &c__9, (ftnlen)2, (ftnlen)8);
-	rllget_(cparal, lx, &c__9, (ftnlen)40);
+	rtlget_("SW", cparas, lx, &c__13, (ftnlen)2, (ftnlen)8);
+	rllget_(cparal, lx, &c__13, (ftnlen)40);
 	lfirst = FALSE_;
     }
-    if (1 <= *idx && *idx <= 9) {
+    if (1 <= *idx && *idx <= 13) {
 	lx[*idx - 1] = *lpara;
     } else {
 	msgdmp_("E", "SWLSVL", "IDX IS OUT OF RANGE.", (ftnlen)1, (ftnlen)6, (
@@ -134,7 +142,7 @@ L_swlsvl:
 /* ----------------------------------------------------------------------- */
 
 L_swlqin:
-    for (n = 1; n <= 9; ++n) {
+    for (n = 1; n <= 13; ++n) {
 	if (lchreq_(cp, cparas + (n - 1 << 3), cp_len, (ftnlen)8) || lchreq_(
 		cp, cparal + (n - 1) * 40, cp_len, (ftnlen)40)) {
 	    *in = n;
