@@ -76,12 +76,12 @@ static integer c__0 = 0;
 	    *, ftnlen, ftnlen), zgdcls_(void), swqcmf_(integer *, char *, 
 	    ftnlen), swcmll_(void), swiget_(char *, integer *, ftnlen), 
 	    zgdopn_(integer *, integer *, integer *, integer *, integer *, 
-	    integer *, integer *, logical *, logical *, logical *, logical *, 
-	    integer *, logical *, logical *, logical *, logical *, logical *, 
-	    integer *, char *, real *, char *, char *, char *, char *, ftnlen,
-	     ftnlen, ftnlen, ftnlen, ftnlen), swlget_(), zgpcls_(void), 
-	    swcset_(char *, char *, ftnlen, ftnlen), swqfnm_(char *, char *, 
-	    ftnlen, ftnlen);
+	    integer *, integer *, real *, logical *, logical *, logical *, 
+	    logical *, integer *, logical *, logical *, logical *, logical *, 
+	    logical *, integer *, char *, real *, char *, char *, char *, 
+	    char *, ftnlen, ftnlen, ftnlen, ftnlen, ftnlen), swlget_(), 
+	    zgpcls_(void), swcset_(char *, char *, ftnlen, ftnlen), swqfnm_(
+	    char *, char *, ftnlen, ftnlen);
     static integer lstdot;
     extern /* Subroutine */ int swrget_(char *, real *, ftnlen), zgpopn_(void)
 	    , zgoopn_(char *, char *, ftnlen, ftnlen), zgocls_(char *, ftnlen)
@@ -102,6 +102,7 @@ static integer c__0 = 0;
     static integer idmpdgt;
     static real rimgcmp;
     extern /* Subroutine */ int zgclini_(char *, logical *, ftnlen);
+    static real rlwfact;
 
     /* Parameter adjustments */
     if (wpx) {
@@ -214,10 +215,12 @@ static integer c__0 = 0;
     swcget_("CIMGFMT ", cimgfmt, (ftnlen)8, (ftnlen)8);
     swrget_("RIMGCMP ", &rimgcmp, (ftnlen)8);
     swlget_("LSEP   ", &lsep, (ftnlen)7);
-    zgdopn_(&iws, &iwidth, &iheigh, &iposx, &iposy, &idmpdgt, &ibgpage, &
-	    lwait, &lwait0, &lwait1, &lalt, &lstdot, &lkey, &ldump, &lwnd, &
-	    lfgbg, &lsep, &ifl, cimgfmt, &rimgcmp, clrmap, cbtmap, cout, cttl,
-	     (ftnlen)8, (ftnlen)80, (ftnlen)80, (ftnlen)80, (ftnlen)80);
+    swrget_("RLWFACT", &rlwfact, (ftnlen)7);
+    zgdopn_(&jws, &iwidth, &iheigh, &iposx, &iposy, &idmpdgt, &ibgpage, &
+	    rlwfact, &lwait, &lwait0, &lwait1, &lalt, &lstdot, &lkey, &ldump, 
+	    &lwnd, &lfgbg, &lsep, &ifl, cimgfmt, &rimgcmp, clrmap, cbtmap, 
+	    cout, cttl, (ftnlen)8, (ftnlen)80, (ftnlen)80, (ftnlen)80, (
+	    ftnlen)80);
 /*        CALL SWLGET('LCOLOR ', LCOLOR) */
 /*        CALL SWLGET('LPRINT ', LPRINT) */
 /*        CALL SWCGET('LPR    ', CLPR  ) */
@@ -500,6 +503,7 @@ L_swclch:
     swqcmf_(&iclrmp, cmap, (ftnlen)80);
     swcset_("CLRMAP", cmap, (ftnlen)6, (ftnlen)80);
     swqfnm_("CLRMAP ", clrmap, (ftnlen)7, (ftnlen)80);
+    swlget_("LFGBG", &lfgbg, (ftnlen)5);
     if (s_cmp(clrmap, " ", (ftnlen)80, (ftnlen)1) == 0) {
 	msgdmp_("E", "SWDOPN", "COLORMAP FILE DOES NOT EXIST.", (ftnlen)1, (
 		ftnlen)6, (ftnlen)29);
