@@ -1,14 +1,21 @@
-/* szsidx.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* ----------------------------------------------------------------------- */
 /*     LINE INDEX ATTRIBUTE */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int szsidx_0_(int n__, integer *index)
 {
@@ -16,14 +23,22 @@
 
     static logical lfrst = TRUE_;
 
+    /* System generated locals */
+    logical L__1;
+
+    /* Local variables */
+    static integer ibgcli;
+    static logical lfcatr;
     static integer iclidx;
     static logical lclatr;
+    extern /* Subroutine */ int sgiget_(char *, integer *, ftnlen), swqfcc_(
+	    logical *);
     static integer iwdidx;
     extern /* Subroutine */ int swqclc_(logical *);
     static logical lwdatr;
     static integer indexz;
-    extern /* Subroutine */ int swscli_(integer *), swqwdc_(logical *), 
-	    swswdi_(integer *);
+    extern /* Subroutine */ int swscli_(integer *, logical *), swqwdc_(
+	    logical *), swswdi_(integer *);
 
     switch(n__) {
 	case 1: goto L_szqidx;
@@ -35,15 +50,26 @@
 	swqclc_(&lclatr);
 	lfrst = FALSE_;
     }
-    iwdidx = *index % 10;
-    iclidx = *index / 10 % 100;
+    sgiget_("IBGCLI", &ibgcli, (ftnlen)6);
+    iwdidx = indexz % 10;
+    iclidx = indexz / 10;
+    if (iclidx == ibgcli) {
+	iclidx = 0;
+    } else {
+	iclidx %= 100;
+	if (iclidx == 0) {
+	    iclidx = 1;
+	}
+    }
     if (! lclatr && iwdidx == 0) {
 	iwdidx = iclidx;
     } else if (! lwdatr && iclidx == 0) {
 	iclidx = iwdidx;
     }
     swswdi_(&iwdidx);
-    swscli_(&iclidx);
+    swqfcc_(&lfcatr);
+    L__1 = ! lfcatr;
+    swscli_(&iclidx, &L__1);
     return 0;
 /* ----------------------------------------------------------------------- */
 
