@@ -1,9 +1,16 @@
-/* ucyady.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -15,7 +22,7 @@ static logical c_false = FALSE_;
 /* ----------------------------------------------------------------------- */
 /*     UCYADY : PLOT DATE AXIS */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int ucyady_(char *cside, integer *jd0, integer *nd, ftnlen 
 	cside_len)
@@ -33,6 +40,10 @@ static logical c_false = FALSE_;
 
     /* Local variables */
     static integer i__;
+    static char ch[2*100];
+    static integer id, nn;
+    static real uy[100];
+    static integer it0, iy0, idi, iml, moi, iti, iyi;
     extern /* Subroutine */ int cladj_(char *, ftnlen);
     static logical label;
     extern /* Subroutine */ int date12_(integer *, integer *, integer *), 
@@ -43,21 +54,16 @@ static logical c_false = FALSE_;
     static logical lbtwn;
     extern /* Subroutine */ int datef2_(integer *, integer *, integer *, 
 	    integer *, integer *);
-    static char ch[2*100];
-    static integer id, nn;
-    static real uy[100];
     extern integer nucday_(char *, integer *, ftnlen);
     extern /* Subroutine */ int msgdmp_(char *, char *, char *, ftnlen, 
 	    ftnlen, ftnlen);
     extern logical luychk_(char *, ftnlen);
     extern /* Subroutine */ int uziget_(char *, integer *, ftnlen), uyplbl_(
 	    char *, integer *, real *, char *, integer *, integer *, ftnlen, 
-	    ftnlen), uzlget_(char *, logical *, ftnlen);
-    static integer it0, iy0;
-    extern /* Subroutine */ int uziset_(char *, integer *, ftnlen), uzlset_(
-	    char *, logical *, ftnlen), uypaxs_(char *, integer *, ftnlen), 
-	    uyptmk_(char *, integer *, real *, integer *, ftnlen);
-    static integer idi, iml, moi, iti, iyi;
+	    ftnlen), uzlget_(char *, logical *, ftnlen), uziset_(char *, 
+	    integer *, ftnlen), uzlset_(char *, logical *, ftnlen), uypaxs_(
+	    char *, integer *, ftnlen), uyptmk_(char *, integer *, real *, 
+	    integer *, ftnlen);
 
     if (! luychk_(cside, (ftnlen)1)) {
 	msgdmp_("E", "UCYADY", "SIDE PARAMETER IS INVALID.", (ftnlen)1, (
@@ -87,6 +93,10 @@ static logical c_false = FALSE_;
 	iml = ndmon_(&iyi, &moi);
 	if (idi < iml - id / 2 && idi % id == 0 || idi == iml) {
 	    ++nn;
+	    if (nn > 100) {
+		msgdmp_("E", "UCYADY", "WORKING AREA IS NOT ENOUGH.", (ftnlen)
+			1, (ftnlen)6, (ftnlen)27);
+	    }
 	    uy[nn - 1] = (real) i__;
 	    ici__1.icierr = 0;
 	    ici__1.icirnum = 1;
@@ -104,9 +114,6 @@ static logical c_false = FALSE_;
 	msgdmp_("W", "UCYADY", "THERE IS NO TICKMARK / LABEL.", (ftnlen)1, (
 		ftnlen)6, (ftnlen)29);
 	return 0;
-    } else if (nn > 100) {
-	msgdmp_("E", "UCYADY", "WORKING AREA IS NOT ENOUGH.", (ftnlen)1, (
-		ftnlen)6, (ftnlen)27);
     }
 /* Writing concatenation */
     i__2[0] = 6, a__1[0] = "ICENTY";
