@@ -1,9 +1,16 @@
-/* uhbraz.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Common Block Declarations */
 
@@ -26,7 +33,7 @@ static real c_b24 = 1.f;
 static integer c__1 = 1;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int uhbraz_(integer *n, real *upx1, real *upx2, real *upy, 
 	integer *itpat1, integer *itpat2, real *rsize)
@@ -40,30 +47,28 @@ static integer c__1 = 1;
 	    ;
 
     /* Local variables */
+    static integer i__;
+    static real dy, rx0, ry0, rx1, ry1, rx2, ry2, vx1, vx2, rot, vxx, uyy, 
+	    vyy;
+    static logical lxc1, lxc2;
     static real uxx1, uxx2;
     static char cobj[80];
     static real uref;
-    static integer i__;
     extern /* Subroutine */ int cdblk_(char *, ftnlen);
     static logical lmiss;
     static real rmiss;
     static logical lyuni;
     static real uymin, uymax;
-    extern /* Subroutine */ int stfpr2_(real *, real *, real *, real *);
-    static real dy;
-    extern /* Subroutine */ int gllget_(char *, logical *, ftnlen);
+    extern /* Subroutine */ int stfpr2_(real *, real *, real *, real *), 
+	    gllget_(char *, logical *, ftnlen);
     static real rundef;
     extern /* Subroutine */ int glrget_(char *, real *, ftnlen), sglget_(char 
 	    *, logical *, ftnlen), msgdmp_(char *, char *, char *, ftnlen, 
 	    ftnlen, ftnlen), sgrget_(char *, real *, ftnlen), stftrf_(real *, 
 	    real *, real *, real *), swocls_(char *, ftnlen), uurget_(char *, 
 	    real *, ftnlen), uuqidv_(real *, real *), swoopn_(char *, char *, 
-	    ftnlen, ftnlen), szcltv_(void);
-    static real rx0, ry0, rx1, ry1, rx2, ry2, vx1, vx2;
-    extern /* Subroutine */ int szstni_(integer *), szoptv_(void), szsttv_(
-	    real *, real *);
-    static real rot, vxx, uyy, vyy;
-    static logical lxc1, lxc2;
+	    ftnlen, ftnlen), szcltv_(void), szstni_(integer *), szoptv_(void),
+	     szsttv_(real *, real *);
 
     /* Fortran I/O blocks */
     static icilist io___12 = { 0, cobj, 0, "(2I8,F8.5)", 80, 1 };
