@@ -1,10 +1,16 @@
-/* Copyright (C) by GFD-Dennou Club, 1999-2000.  All rights reserved. */
-/* usyoff.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -13,6 +19,8 @@ static integer c__2 = 2;
 /* ----------------------------------------------------------------------- */
 /*     USPACK OFFSET CHEK (Y-AXIS)                    S. Sakai  90/08/18 */
 /* ----------------------------------------------------------------------- */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/* ----------------------------------------------------------------------- */
 /* Subroutine */ int usyoff_(char *cys, ftnlen cys_len)
 {
     /* System generated locals */
@@ -23,8 +31,8 @@ static integer c__2 = 2;
     /* Subroutine */ int s_cat(char *, char **, integer *, integer *, ftnlen);
 
     /* Local variables */
-    static real roff, soff;
     static char cp[8];
+    static real roff, soff;
     extern /* Subroutine */ int msgdmp_(char *, char *, char *, ftnlen, 
 	    ftnlen, ftnlen), usrget_(char *, real *, ftnlen), uzrget_(char *, 
 	    real *, ftnlen);
@@ -36,7 +44,7 @@ static integer c__2 = 2;
 	s_cat(cp, a__1, i__1, &c__2, (ftnlen)8);
 	usrget_(cp, &soff, (ftnlen)8);
 	uzrget_(cp, &roff, (ftnlen)8);
-	roff = dmax(roff,soff);
+	roff = max(roff,soff);
 	uzrget_(cp, &roff, (ftnlen)8);
     } else {
 	msgdmp_("E", "USYOFF", "INVALID CYS", (ftnlen)1, (ftnlen)6, (ftnlen)
