@@ -1,14 +1,21 @@
-/* luychk.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* ----------------------------------------------------------------------- */
 /*     LUYCHK : CHECK SIDE PARAMETER */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 logical luychk_(char *cside, ftnlen cside_len)
 {
@@ -16,8 +23,8 @@ logical luychk_(char *cside, ftnlen cside_len)
     logical ret_val;
 
     /* Local variables */
-    extern /* Subroutine */ int cupper_(char *, ftnlen);
     static char csx[1];
+    extern /* Subroutine */ int cupper_(char *, ftnlen);
 
     *(unsigned char *)csx = *(unsigned char *)cside;
     cupper_(csx, (ftnlen)1);
