@@ -1,22 +1,30 @@
-/* Copyright (C) by GFD-Dennou Club, 1999-2000.  All rights reserved. */
-/* iblkgt.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* ----------------------------------------------------------------------- */
 /*     IBLKGT */
 /* ----------------------------------------------------------------------- */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/* ----------------------------------------------------------------------- */
 integer iblkgt_(real *rx, integer *n, real *rr)
 {
     /* System generated locals */
     integer ret_val, i__1;
 
     /* Local variables */
-    extern logical lrgt_(real *, real *);
     static integer i__;
+    extern logical lrgt_(real *, real *);
     extern /* Subroutine */ int msgdmp_(char *, char *, char *, ftnlen, 
 	    ftnlen, ftnlen);
 
