@@ -1,10 +1,16 @@
-/* Copyright (C) by GFD-Dennou Club, 1999-2000.  All rights reserved. */
-/* rgngt.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -13,16 +19,18 @@ static integer c__10 = 10;
 /* ----------------------------------------------------------------------- */
 /*     RGNGT */
 /* ----------------------------------------------------------------------- */
-doublereal rgngt_(real *rx)
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/* ----------------------------------------------------------------------- */
+real rgngt_(real *rx)
 {
     /* System generated locals */
     real ret_val;
 
     /* Local variables */
-    extern /* Subroutine */ int gngt_(real *, real *, integer *);
-    extern doublereal rexp_(real *, integer *, integer *);
     static integer ip;
     static real bx;
+    extern /* Subroutine */ int gngt_(real *, real *, integer *);
+    extern real rexp_(real *, integer *, integer *);
 
     gngt_(rx, &bx, &ip);
     ret_val = rexp_(&bx, &c__10, &ip);
