@@ -1,14 +1,21 @@
-/* shmw2s.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* ********************************************************************** */
 /*     TRANSFORM WAVE INTO SPECTRA */
 /* ********************************************************************** */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int shmw2s_(integer *mm, integer *jm, integer *isw, real *w, 
 	real *s, real *sd, real *pm, real *xs, real *xc, real *px, real *wy, 
@@ -19,28 +26,26 @@
 	     wy_offset, wx_dim1, wx_offset, z_dim1, z_dim2, z_offset, i__1;
 
     /* Local variables */
-    static integer m, n;
+    static integer m, n, li, lr;
     extern /* Subroutine */ int shnm2l_(integer *, integer *, integer *, 
-	    integer *, integer *);
-    static integer li, lr;
-    extern /* Subroutine */ int shppma_(integer *, integer *, integer *, real 
-	    *, real *, real *, real *), shlfwm_(integer *, integer *, integer 
-	    *, integer *, real *, real *, real *, real *, real *, real *, 
-	    real *, real *, real *), shmsri_(integer *, integer *, real *, 
-	    real *);
+	    integer *, integer *), shppma_(integer *, integer *, integer *, 
+	    real *, real *, real *, real *), shlfwm_(integer *, integer *, 
+	    integer *, integer *, real *, real *, real *, real *, real *, 
+	    real *, real *, real *, real *), shmsri_(integer *, integer *, 
+	    real *, real *);
 
     /* Parameter adjustments */
     --r__;
     --s;
     z_dim1 = *jm;
     z_dim2 = *jm - 0 + 1;
-    z_offset = 1 + z_dim1 * (0 + z_dim2 * 1);
+    z_offset = 1 + z_dim1 * (0 + z_dim2);
     z__ -= z_offset;
     wx_dim1 = *jm - 0 + 1;
-    wx_offset = 0 + wx_dim1 * 1;
+    wx_offset = 0 + wx_dim1;
     wx -= wx_offset;
     wy_dim1 = *jm - 0 + 1;
-    wy_offset = 0 + wy_dim1 * 1;
+    wy_offset = 0 + wy_dim1;
     wy -= wy_offset;
     px_dim2 = *jm - 0 + 1;
     px_offset = 1 + 2 * (0 + px_dim2 * 0);
